==> eventum-2.1.tar.gz: eventum-2.1/reports/workload_date_range.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
// +----------------------------------------------------------------------+
// | Eventum - Issue Tracking System                                      |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to:                           |
// |                                                                      |
// | Free Software Foundation, Inc.                                       |
// | 59 Temple Place - Suite 330                                          |
// | Boston, MA 02111-1307, USA.                                          |
// +----------------------------------------------------------------------+
// | Authors: Bryan Alsdorf <bryan@mysql.com>                             |
// +----------------------------------------------------------------------+
//
// @(#) $Id: workload_date_range.php 3206 2007-01-24 20:24:35Z glen $
//
require_once(dirname(__FILE__) . "/../init.php");
require_once(APP_INC_PATH . "class.template.php");
require_once(APP_INC_PATH . "class.auth.php");
require_once(APP_INC_PATH . "class.report.php");
require_once(APP_INC_PATH . "class.session.php");
require_once(APP_INC_PATH . "db_access.php");

$tpl = new Template_API();
$tpl->setTemplate("reports/workload_date_range.tpl.html");

Auth::checkAuthentication(APP_COOKIE);

if (Auth::getCurrentRole() <= User::getRoleID("Customer")) {
    echo "Invalid role";
    exit;
}

$types = array(
    "individual"    =>  "Individual",
    "aggregate"     =>  "Aggregate"
);


if (count(@$_REQUEST["start"]) > 0 &&
        (@$_REQUEST["start"]["Year"] != 0) &&
        (@$_REQUEST["start"]["Month"] != 0) &&
        (@$_REQUEST["start"]["Day"] != 0)) {
    $start_date = join("-", $_REQUEST["start"]);
} else {
    // if empty start date, set to be a month ago
    $start_date = date("Y-m-d", time() - MONTH);
}
if (count(@$_REQUEST["end"]) > 0 &&
        (@$_REQUEST["end"]["Year"] != 0) &&
        (@$_REQUEST["end"]["Month"] != 0) &&
        (@$_REQUEST["end"]["Day"] != 0)) {
    $end_date = join("-", $_REQUEST["end"]);
} else {
    $end_date = date("Y-m-d");
}


if (!empty($_REQUEST["interval"])) {
    $data = Report::getWorkloadByDateRange($_REQUEST["interval"], $_REQUEST["type"], $start_date, date('Y-m-d', (strtotime($end_date) + DAY)));
    Session::set("workload_date_range_data", $data);
    $tpl->assign("data", $data);
  //  echo "<pre>";print_r($data);echo "</pre>";
}

$tpl->assign(array(
    "interval"  =>  @$_REQUEST["interval"],
    "types" =>  $types,
    "type"  =>  @$_REQUEST["type"],
    "start_date"    =>  $start_date,
    "end_date"  =>  $end_date
));
$tpl->displayTemplate();

==> eventum-2.1.1.tar.gz: eventum-2.1.1/reports/workload_date_range.php <==
<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 encoding=utf-8: */
// +----------------------------------------------------------------------+
// | Eventum - Issue Tracking System                                      |
// +----------------------------------------------------------------------+
// | Copyright (c) 2003, 2004, 2005, 2006, 2007 MySQL AB                  |
// |                                                                      |
// | This program is free software; you can redistribute it and/or modify |
// | it under the terms of the GNU General Public License as published by |
// | the Free Software Foundation; either version 2 of the License, or    |
// | (at your option) any later version.                                  |
// |                                                                      |
// | This program is distributed in the hope that it will be useful,      |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of       |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        |
// | GNU General Public License for more details.                         |
// |                                                                      |
// | You should have received a copy of the GNU General Public License    |
// | along with this program; if not, write to:                           |
// |                                                                      |
// | Free Software Foundation, Inc.                                       |
// | 59 Temple Place - Suite 330                                          |
// | Boston, MA 02111-1307, USA.                                          |
// +----------------------------------------------------------------------+
// | Authors: Bryan Alsdorf <bryan@mysql.com>                             |
// +----------------------------------------------------------------------+
//
// @(#) $Id: workload_date_range.php 3499 2007-12-05 07:00:18Z balsdorf $
//
require_once(dirname(__FILE__) . "/../init.php");
require_once(APP_INC_PATH . "class.template.php");
require_once(APP_INC_PATH . "class.auth.php");
require_once(APP_INC_PATH . "class.report.php");
require_once(APP_INC_PATH . "class.session.php");
require_once(APP_INC_PATH . "class.category.php");
require_once(APP_INC_PATH . "db_access.php");

$tpl = new Template_API();
$tpl->setTemplate("reports/workload_date_range.tpl.html");

Auth::checkAuthentication(APP_COOKIE);

if (Auth::getCurrentRole() <= User::getRoleID("Customer")) {
    echo "Invalid role";
    exit;
}

$prj_id = Auth::getCurrentProject();

$types = array(
    "individual"    =>  "Individual",
    "aggregate"     =>  "Aggregate"
);


if (count(@$_REQUEST["start"]) > 0 &&
        (@$_REQUEST["start"]["Year"] != 0) &&
        (@$_REQUEST["start"]["Month"] != 0) &&
        (@$_REQUEST["start"]["Day"] != 0)) {
    $start_date = join("-", $_REQUEST["start"]);
} else {
    // if empty start date, set to be a month ago
    $start_date = date("Y-m-d", time() - MONTH);
}
if (count(@$_REQUEST["end"]) > 0 &&
        (@$_REQUEST["end"]["Year"] != 0) &&
        (@$_REQUEST["end"]["Month"] != 0) &&
        (@$_REQUEST["end"]["Day"] != 0)) {
    $end_date = join("-", $_REQUEST["end"]);
} else {
    $end_date = date("Y-m-d");
}


if (!empty($_REQUEST["interval"])) {
    $data = Report::getWorkloadByDateRange($_REQUEST["interval"], $_REQUEST["type"], $start_date, date('Y-m-d', (strtotime($end_date) + DAY)), @$_REQUEST['category']);
    Session::set("workload_date_range_data", $data);
    $tpl->assign("data", $data);
  //  echo "<pre>";print_r($data);echo "</pre>";
}

$tpl->assign(array(
    "interval"  =>  @$_REQUEST["interval"],
    "types" =>  $types,
    "type"  =>  @$_REQUEST["type"],
    "start_date"    =>  $start_date,
    "end_date"  =>  $end_date,
    'categories'    =>  Category::getAssocList($prj_id),
    'category'  =>  @$_REQUEST['category'],
));
$tpl->displayTemplate();
